@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.1057';
+our $VERSION = '0.1058';
 
 use Carp        ();
 use File::Spec  ();
@@ -14,15 +14,18 @@ use Text::Xslate::Util qw(
     $DEBUG
     mark_raw unmark_raw
     html_escape escaped_string
-    uri_escape
+    uri_escape html_builder
 );
 
 our @ISA = qw(Text::Xslate::Engine Exporter);
 
 our @EXPORT_OK = qw(
-    mark_raw unmark_raw
-    escaped_string html_escape
+    mark_raw
+    unmark_raw
+    escaped_string
+    html_escape
     uri_escape
+    html_builder
 );
 
 # load backend (XS or PP)
@@ -504,7 +507,7 @@ Text::Xslate - High performance template engine
 
 =head1 VERSION
 
-This document describes Text::Xslate version 0.1057.
+This document describes Text::Xslate version 0.1058.
 
 =head1 SYNOPSIS
 
@@ -857,6 +860,28 @@ Escapes URI unsafe characters in I<$str>, and returns it.
 
 This function is available in templates as the C<uri> filter.
 
+=head3 C<< html_builder { block } | \&function :CodeRef >>
+
+Wraps I<&function> with C<mark_raw> so that the new subroutine returns
+a raw string.
+
+This function is used to tell the xslate engine that I<&function> is an
+HTML builder that returns HTML sources. For example:
+
+    sub some_html_builder {
+        my $html;
+        # build HTML ...
+        return $html;
+    }
+
+    my $tx = Text::Xslate->new(
+        function => {
+            some_html_builder => html_builder(\&some_html_builder),
+        },
+    );
+
+See also L<Text::Xslate::Manual::Cookbook>.
+
 =head2 Command line interface
 
 The C<xslate(1)> command is provided as a CLI to the Text::Xslate module,
